@@ -15,7 +15,7 @@
 #
 #
 
-from emailclient import EmailClient
+from unforward.emailclients.emailclient import EmailClient
 from unforward.errors import ExtractionError
 from bs4 import BeautifulSoup
 from pprint import pprint
@@ -32,7 +32,8 @@ class GmailClient(EmailClient):
     def check_match(self, string):
         """ This method should look at the given string, and as quickly as possible determine if it contains a
             forward from this email client. """
-        return string.find('gmail_sendername') != -1 and string.find('---------- Forwarded message ----------')
+        string = str(string)
+        return string.find('gmail_sendername') != -1 and string.find('---------- Forwarded message ----------') != -1
     
     def extract_from_html(self, string):
         try:
