@@ -46,6 +46,6 @@ class ExtractorTest(unittest.TestCase):
         with open(unforward.get_data("examples/gmail_forward_2.mime")) as f:
             mimetext = ''.join(f.readlines())
             result = self.extractor.extract(mimetext)
-            expected = {'body': '<div><div><div>Comodo,<br/>\n<br/></div>I have to say that I am impressed by your thoroughness on our company background check. 5 stars for actually doing a background check.<br/><br/></div>Our accountant Tara is registered under the Chartered Professional Accountants of Ontario.<br/>\n<br/></div>Brad<br/>', 'sender': u'brad@getsensibill.com'}
+            expected = {'body': '<div><div><div>Comodo,<br/>\n<br/></div>I have to say that I am impressed by your thoroughness on our company background check. 5 stars for actually doing a background check.<br/><br/></div>Our accountant Tara is registered under the Chartered Professional Accountants of Ontario.<br/>\n<br/></div>Brad<br/>', 'sender': 'brad@getsensibill.com'}
             self.assertEqual(result, expected)
         
